aboutsummaryrefslogtreecommitdiffstats
path: root/themes/default/js/ui/jquery.ui.accordion.js
diff options
context:
space:
mode:
Diffstat (limited to 'themes/default/js/ui/jquery.ui.accordion.js')
-rw-r--r--themes/default/js/ui/jquery.ui.accordion.js9
1 files changed, 7 insertions, 2 deletions
diff --git a/themes/default/js/ui/jquery.ui.accordion.js b/themes/default/js/ui/jquery.ui.accordion.js
index db9d24bc6..31080d3d3 100644
--- a/themes/default/js/ui/jquery.ui.accordion.js
+++ b/themes/default/js/ui/jquery.ui.accordion.js
@@ -1,5 +1,5 @@
/*
* jQuery UI Accordion 1.8.10
*
* Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
@@ -114,6 +114,7 @@ $.widget( "ui.accordion", {
.not( self.active || "" )
.attr({
"aria-expanded": "false",
+ "aria-selected": "false",
tabIndex: -1
})
.next()
@@ -126,6 +127,7 @@ $.widget( "ui.accordion", {
self.active
.attr({
"aria-expanded": "true",
+ "aria-selected": "true",
tabIndex: 0
});
}
@@ -173,6 +175,7 @@ $.widget( "ui.accordion", {
.removeClass( "ui-accordion-header ui-accordion-disabled ui-helper-reset ui-state-default ui-corner-all ui-state-active ui-state-disabled ui-corner-top" )
.removeAttr( "role" )
.removeAttr( "aria-expanded" )
+ .removeAttr( "aria-selected" )
.removeAttr( "tabIndex" );
this.headers.find( "a" ).removeAttr( "tabIndex" );
@@ -477,12 +480,14 @@ $.widget( "ui.accordion", {
toHide.prev()
.attr({
"aria-expanded": "false",
+ "aria-selected": "false",
tabIndex: -1
})
.blur();
toShow.prev()
.attr({
"aria-expanded": "true",
+ "aria-selected": "true",
tabIndex: 0
})
.focus();
@@ -513,7 +518,7 @@ $.widget( "ui.accordion", {
});
$.extend( $.ui.accordion, {
- version: "1.8.10",
+ version: "1.8.16",
animations: {
slide: function( options, additions ) {
options = $.extend({
@@ -1,5 +1,5 @@
/*
- * jQuery UI Accordion 1.8.10
+ * jQuery UI Accordion 1.8.16
*
* Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)